@@ -5,6 +5,7 @@ use strict;
 use DBI;
 use Carp();
 use Bit::Vector::Overload;
+use SQL::ReservedWords();
 
 use Time::Clock;
 use Rose::DateTime::Util();
@@ -18,7 +19,7 @@ our @ISA = qw(Rose::Object);
 
 our $Error;
 
-our $VERSION = '0.722';
+our $VERSION = '0.723';
 
 our $Debug = 0;
 
@@ -956,7 +957,9 @@ sub unquote_column_name
 
 *unquote_table_name = \&unquote_column_name;
 
-sub is_reserved_word { 0 }
+#sub is_reserved_word { 0 }
+
+*is_reserved_word = \&SQL::ReservedWords::is_reserved;
 
 BEGIN
 {
@@ -1916,7 +1919,7 @@ Rose::DB - A DBI wrapper and abstraction layer.
 
 =head1 DESCRIPTION
 
-L<Rose::DB> is a wrapper and abstraction layer for C<DBI>-related functionality.  A L<Rose::DB> object "has a" L<DBI> object; it is not a subclass of L<DBI>.
+L<Rose::DB> is a wrapper and abstraction layer for L<DBI>-related functionality.  A L<Rose::DB> object "has a" L<DBI> object; it is not a subclass of L<DBI>.
 
 Please see the L<tutorial|Rose::DB::Tutorial> (perldoc Rose::DB::Tutorial) for an example usage scenario that reflects "best practices" for this module.
 
@@ -2155,6 +2158,8 @@ The default mapping of driver names to class names is as follows:
     mysql    -> Rose::DB::MySQL
     pg       -> Rose::DB::Pg
     informix -> Rose::DB::Informix
+    sqlite   -> Rose::DB::SQLite
+    oracle   -> Rose::DB::Oracle
     generic  -> Rose::DB::Generic
 
 The class mapped to the special driver name "generic" will be used for any driver name that does not have an entry in the map.
@@ -2297,13 +2302,13 @@ Unregisters an entire domain.  Returns true if the domain was unregistered succe
 
 Unregistering a domain removes all knowledge of all of the data sources that existed under it.  This may be harmful to any existing L<Rose::DB> objects that are associated with any of those data sources.
 
-=item use_private_registry
+=item B<use_private_registry>
 
-This is a convenience method used to give a class its own private L<registry|/registry>.  In other words, this:
+This method is used to give a class its own private L<registry|/registry>.  In other words, this:
 
     __PACKAGE__->use_private_registry;
 
-is equivalent to this:
+is roughly equivalent to this:
 
     use Rose::DB::Registry;
     __PACKAGE__->registry(Rose::DB::Registry->new);
@@ -2808,6 +2813,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-DB>
 =head1 CONTRIBUTORS
 
 Ron Savage
+
 Lucian Dragus
 
 =head1 AUTHOR
